@@ -37,8 +37,8 @@ app = dash.Dash(external_stylesheets=[dbc.themes.BOOTSTRAP])
 app.title = 'arxivbox'
 
 
-if not os.path.isfile('logfav'):
-  with open('logfav', 'w+') as f:
+if not os.path.isfile('arxivbox/logfav'):
+  with open('arxivbox/logfav', 'w+') as f:
     f.close()
 
 def loading(children):
@@ -88,10 +88,10 @@ def update_output_div(n_click, check_all, select_id, string, select_max, select_
   #with gzip.open('links-between-papers-and-code.json.gz', 'rt', encoding='UTF-8') as zipfile:
   #  pwcdata = json.load(zipfile)
 
-  with open('logfav', 'r') as f:
+  with open('arxivbox/logfav', 'r') as f:
     favlist = [ii[:-1][:-2] for ii in f.readlines()]
     f.close()
-  with open('logfav', 'r') as f:
+  with open('arxivbox/logfav', 'r') as f:
     favlistv = [ii[:-1] for ii in f.readlines()]
     f.close()
 
@@ -352,7 +352,7 @@ def update_fav(checked):
       if dash.callback_context.triggered[0]['value'] == True:
         arxivid = dash.callback_context.triggered[0]['prop_id'].split('/abs/')[1].split('","type":"check-fav"')[0]
 
-        with open('logfav', 'a+') as f:
+        with open('arxivbox/logfav', 'a+') as f:
           f.write(arxivid + '\n')
           f.close()
 
@@ -361,7 +361,7 @@ def update_fav(checked):
         arxivid = dash.callback_context.triggered[0]['prop_id'].split('/abs/')[1].split('","type":"check-fav"')[0]
         #print (arxivid)
 
-        with open('logfav', 'r') as f:
+        with open('arxivbox/logfav', 'r') as f:
           favlist = [ii[:-1] for ii in f.readlines()]
           f.close()
 
@@ -371,7 +371,7 @@ def update_fav(checked):
 
         favlist = [i for j, i in enumerate(favlist) if i != arxivid]
 
-        with open('logfav', 'w+') as f:
+        with open('arxivbox/logfav', 'w+') as f:
           for i in favlist:
             f.write(i + '\n')
           f.close()
